@@ -289,7 +289,7 @@ fs_rawudp_component_class_init (FsRawUdpComponentClass *klass)
           "The component id",
           "The id of this component",
           1, G_MAXUINT, 1,
-          G_PARAM_CONSTRUCT_ONLY | G_PARAM_READWRITE));
+          G_PARAM_CONSTRUCT_ONLY | G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 
 
   g_object_class_install_property (gobject_class,
@@ -298,7 +298,7 @@ fs_rawudp_component_class_init (FsRawUdpComponentClass *klass)
           "Whether to send from this transmitter",
           "If set to FALSE, the transmitter will stop sending to this person",
           TRUE,
-          G_PARAM_READWRITE));
+          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 
   g_object_class_install_property (gobject_class,
       PROP_IP,
@@ -306,7 +306,7 @@ fs_rawudp_component_class_init (FsRawUdpComponentClass *klass)
           "The local IP of this component",
           "The IPv4 address as a x.x.x.x string",
           NULL,
-          G_PARAM_CONSTRUCT_ONLY | G_PARAM_WRITABLE));
+          G_PARAM_CONSTRUCT_ONLY | G_PARAM_WRITABLE | G_PARAM_STATIC_STRINGS));
 
   g_object_class_install_property (gobject_class,
       PROP_PORT,
@@ -314,7 +314,7 @@ fs_rawudp_component_class_init (FsRawUdpComponentClass *klass)
           "The local port requested for this component",
           "The IPv4 UDP port",
           1, 65535, 7078,
-          G_PARAM_CONSTRUCT_ONLY | G_PARAM_WRITABLE));
+          G_PARAM_CONSTRUCT_ONLY | G_PARAM_WRITABLE | G_PARAM_STATIC_STRINGS));
 
 
   g_object_class_install_property (gobject_class,
@@ -323,7 +323,7 @@ fs_rawudp_component_class_init (FsRawUdpComponentClass *klass)
           "The IP address of the STUN server",
           "The IPv4 address of the STUN server as a x.x.x.x string",
           NULL,
-          G_PARAM_CONSTRUCT_ONLY | G_PARAM_WRITABLE));
+          G_PARAM_CONSTRUCT_ONLY | G_PARAM_WRITABLE | G_PARAM_STATIC_STRINGS));
 
   g_object_class_install_property (gobject_class,
       PROP_STUN_PORT,
@@ -331,7 +331,7 @@ fs_rawudp_component_class_init (FsRawUdpComponentClass *klass)
           "The port of the STUN server",
           "The IPv4 UDP port of the STUN server as a ",
           1, 65535, 3478,
-          G_PARAM_CONSTRUCT_ONLY | G_PARAM_WRITABLE));
+          G_PARAM_CONSTRUCT_ONLY | G_PARAM_WRITABLE | G_PARAM_STATIC_STRINGS));
 
   g_object_class_install_property (gobject_class,
       PROP_STUN_TIMEOUT,
@@ -339,7 +339,7 @@ fs_rawudp_component_class_init (FsRawUdpComponentClass *klass)
           "The timeout for the STUN reply",
           "How long to wait for for the STUN reply (in seconds) before giving up",
           1,  MAX_STUN_TIMEOUT, DEFAULT_STUN_TIMEOUT,
-          G_PARAM_CONSTRUCT_ONLY | G_PARAM_WRITABLE));
+          G_PARAM_CONSTRUCT_ONLY | G_PARAM_WRITABLE | G_PARAM_STATIC_STRINGS));
 
 
   g_object_class_install_property (gobject_class,
@@ -348,7 +348,7 @@ fs_rawudp_component_class_init (FsRawUdpComponentClass *klass)
           "The transmitter object",
           "The rawudp transmitter object",
           FS_TYPE_RAWUDP_TRANSMITTER,
-          G_PARAM_CONSTRUCT_ONLY | G_PARAM_WRITABLE));
+          G_PARAM_CONSTRUCT_ONLY | G_PARAM_WRITABLE | G_PARAM_STATIC_STRINGS));
 
 
   g_object_class_install_property (gobject_class,
@@ -357,7 +357,7 @@ fs_rawudp_component_class_init (FsRawUdpComponentClass *klass)
           "A Forced candidate",
           "This candidate is built from a user preference",
           FS_TYPE_CANDIDATE,
-          G_PARAM_WRITABLE));
+          G_PARAM_WRITABLE | G_PARAM_STATIC_STRINGS));
 
   g_object_class_install_property (gobject_class,
       PROP_ASSOCIATE_ON_SOURCE,
@@ -366,7 +366,7 @@ fs_rawudp_component_class_init (FsRawUdpComponentClass *klass)
           "Whether to associate incoming data stream based on the"
           " source address",
           TRUE,
-          G_PARAM_CONSTRUCT_ONLY | G_PARAM_WRITABLE));
+          G_PARAM_CONSTRUCT_ONLY | G_PARAM_WRITABLE | G_PARAM_STATIC_STRINGS));
 
 #ifdef HAVE_GUPNP
     g_object_class_install_property (gobject_class,
@@ -375,7 +375,7 @@ fs_rawudp_component_class_init (FsRawUdpComponentClass *klass)
           "Try to map ports using UPnP",
           "Tries to map ports using UPnP if enabled",
           TRUE,
-          G_PARAM_CONSTRUCT_ONLY | G_PARAM_READWRITE));
+          G_PARAM_CONSTRUCT_ONLY | G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 
   g_object_class_install_property (gobject_class,
       PROP_UPNP_DISCOVERY,
@@ -383,7 +383,7 @@ fs_rawudp_component_class_init (FsRawUdpComponentClass *klass)
           "Try to use UPnP to find the external IP address",
           "Tries to discovery the external IP with UPnP if stun fails",
           TRUE,
-          G_PARAM_CONSTRUCT_ONLY | G_PARAM_READWRITE));
+          G_PARAM_CONSTRUCT_ONLY | G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 
   g_object_class_install_property (gobject_class,
       PROP_UPNP_MAPPING_TIMEOUT,
@@ -392,7 +392,7 @@ fs_rawudp_component_class_init (FsRawUdpComponentClass *klass)
           "The UPnP port mappings expire after this period if the app has"
           " crashed (in seconds)",
           0, G_MAXUINT32, DEFAULT_UPNP_MAPPING_TIMEOUT,
-          G_PARAM_CONSTRUCT_ONLY | G_PARAM_READWRITE));
+          G_PARAM_CONSTRUCT_ONLY | G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 
   g_object_class_install_property (gobject_class,
       PROP_UPNP_DISCOVERY_TIMEOUT,
@@ -401,7 +401,7 @@ fs_rawudp_component_class_init (FsRawUdpComponentClass *klass)
           "After this period, UPnP discovery is considered to have failed"
           " and the local IP is returned",
           0, G_MAXUINT32, DEFAULT_UPNP_DISCOVERY_TIMEOUT,
-          G_PARAM_CONSTRUCT_ONLY | G_PARAM_READWRITE));
+          G_PARAM_CONSTRUCT_ONLY | G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 
   g_object_class_install_property (gobject_class,
       PROP_UPNP_IGD,
@@ -409,7 +409,7 @@ fs_rawudp_component_class_init (FsRawUdpComponentClass *klass)
           "The GUPnPSimpleIgdThread object",
           "This is the GUPnP IGD abstraction object",
           GUPNP_TYPE_SIMPLE_IGD_THREAD,
-          G_PARAM_CONSTRUCT_ONLY | G_PARAM_WRITABLE));
+          G_PARAM_CONSTRUCT_ONLY | G_PARAM_WRITABLE | G_PARAM_STATIC_STRINGS));
 #endif
 
    /**
@@ -1111,6 +1111,10 @@ _upnp_mapped_external_port (GUPnPSimpleIgdThread *igd, gchar *proto,
       external_ip,
       external_port);
 
+  GST_DEBUG ("Got UPnP Candidate c:%d ext-ip:%s ext-port:%u"
+      " int-ip:%s int-port:%u", self->priv->component, external_ip,
+      external_port, local_ip, local_port);
+
   FS_RAWUDP_COMPONENT_UNLOCK (self);
 
   fs_rawudp_component_maybe_emit_local_candidates (self);
@@ -1121,6 +1125,8 @@ _upnp_discovery_timeout (gpointer user_data)
 {
   FsRawUdpComponent *self = user_data;
 
+  GST_DEBUG ("UPnP timed out on component %d", self->priv->component);
+
   FS_RAWUDP_COMPONENT_LOCK (self);
   g_source_unref (self->priv->upnp_discovery_timeout_src);
   self->priv->upnp_discovery_timeout_src = NULL;
@@ -1195,6 +1201,8 @@ fs_rawudp_component_gather_local_candidates (FsRawUdpComponent *self,
         FS_RAWUDP_COMPONENT_UNLOCK (self);
       }
 
+      GST_DEBUG ("Doing UPnP Discovery for local ip:%s port:%s", ip, port);
+
       gupnp_simple_igd_add_port (GUPNP_SIMPLE_IGD (self->priv->upnp_igd),
           "UDP", port, ip, port, self->priv->upnp_mapping_timeout,
           "Farsight Raw UDP transmitter");
@@ -1212,6 +1220,12 @@ fs_rawudp_component_gather_local_candidates (FsRawUdpComponent *self,
         FS_RAWUDP_COMPONENT_UNLOCK (self);
       }
     }
+    else
+    {
+      FS_RAWUDP_COMPONENT_LOCK (self);
+      fs_rawudp_component_stop_upnp_discovery_locked (self);
+      FS_RAWUDP_COMPONENT_UNLOCK (self);
+    }
 
     /* free list of ips */
     g_list_foreach (ips, (GFunc) g_free, NULL);
@@ -1223,7 +1237,7 @@ fs_rawudp_component_gather_local_candidates (FsRawUdpComponent *self,
   if (self->priv->stun_ip && self->priv->stun_port)
     return fs_rawudp_component_start_stun (self, error);
 #ifdef HAVE_GUPNP
-  else if (!self->priv->upnp_igd || !self->priv->upnp_discovery)
+  else if (!self->priv->upnp_signal_id)
     return fs_rawudp_component_emit_local_candidates (self, error);
   else
     return TRUE;
@@ -1236,11 +1250,26 @@ fs_rawudp_component_gather_local_candidates (FsRawUdpComponent *self,
 static gboolean
 fs_rawudp_component_send_stun_locked (FsRawUdpComponent *self, GError **error)
 {
+  socklen_t socklen = 0;
+
+  switch (self->priv->stun_sockaddr.ss_family)
+  {
+    case AF_INET:
+      socklen = sizeof(struct sockaddr_in);
+      break;
+    case AF_INET6:
+      socklen = sizeof(struct sockaddr_in6);
+      break;
+    default:
+      g_set_error (error, FS_ERROR, FS_ERROR_INVALID_ARGUMENTS,
+          "Unknown address family for stun server");
+      return FALSE;
+  }
+
   return fs_rawudp_transmitter_udpport_sendto (self->priv->udpport,
       (gchar*) self->priv->stun_buffer,
       stun_message_length (&self->priv->stun_message),
-      (const struct sockaddr *)&self->priv->stun_sockaddr,
-      sizeof (self->priv->stun_sockaddr), error);
+      (const struct sockaddr *)&self->priv->stun_sockaddr, socklen, error);
 }
 
 static gboolean
